"use strict";
var React = require("react");
var EventEmitter = require("events");
var enzyme_1 = require("enzyme");
var index_1 = require("../index");
var TestUtils = require("react-addons-test-utils");
var testStory = function () { return function () { return React.createElement("p", null, "Hello World!"); }; };
describe("Background Decorator", function () {
    it("should exist", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: testStory, channel: SpiedChannel}));
        expect(backgroundDecorator).toBeDefined();
    });
    it("should initially have a transparent background state", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: testStory, channel: SpiedChannel}));
        expect(backgroundDecorator.state().background).toBe("transparent");
    });
    it("should have a background matching its state", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: testStory, channel: SpiedChannel}));
        expect(backgroundDecorator.html().match(/background:transparent/gmi).length).toBe(1);
    });
    it("should set internal state when background event called", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: testStory, channel: SpiedChannel}));
        SpiedChannel.emit("background", "#123456");
        expect(backgroundDecorator.state().background).toBe("#123456");
    });
    it("should send background-unset event when the component unmounts", function () {
        var SpiedChannel = new EventEmitter();
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: testStory, channel: SpiedChannel}));
        var spy = jest.fn();
        SpiedChannel.on("background-unset", spy);
        backgroundDecorator.unmount();
        expect(spy).toBeCalled();
    });
    it("should send background-set event when the component mounts", function () {
        var SpiedChannel = new EventEmitter();
        var spy = jest.fn();
        SpiedChannel.on("background-set", spy);
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: testStory, channel: SpiedChannel}));
        expect(spy).toBeCalled();
    });
    it("should update story on change", function () {
        var SpiedChannel = new EventEmitter();
        var nextStory = jest.fn(function () { return React.createElement("p", null, "I am next story!"); });
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: testStory, channel: SpiedChannel}));
        backgroundDecorator.setProps({ story: nextStory });
        expect(nextStory).toBeCalled();
    });
    it("should not update story on other props change", function () {
        var SpiedChannel = new EventEmitter();
        var story = jest.fn(function () { return React.createElement("p", null, "I am the only one!"); });
        var backgroundDecorator = enzyme_1.shallow(React.createElement(index_1.BackgroundDecorator, {story: story, channel: SpiedChannel}));
        backgroundDecorator.setProps({ randomProp: true });
        expect(story.mock.calls.length).toBe(1);
    });
});
//# sourceMappingURL=index.js.map